| Title: | Interactive Statistical Analysis and Machine Learning Platform |
| Version: | 0.2.0 |
| Description: | A 'Shiny'-based interactive platform for end-to-end data science workflows. Provides modules for data import (CSV, 'Excel', RDS, TXT), data preprocessing (missing value imputation, encoding, scaling, outlier removal), exploratory data analysis with interactive plots and normality tests, supervised learning (regression and classification each with eight algorithms), and unsupervised learning (k-means, hierarchical clustering, density-based spatial clustering of applications with noise). Designed for students and practitioners in data science and artificial intelligence. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| Language: | en-US |
| URL: | https://github.com/mohsenmehdinia/DrData |
| BugReports: | https://github.com/mohsenmehdinia/DrData/issues |
| RoxygenNote: | 7.3.3 |
| Imports: | shiny (≥ 1.7.0), stats, utils |
| Suggests: | shinydashboard, plotly, DT, ggplot2, dplyr, tidyr, readr, readxl, caret, randomForest, rpart, rpart.plot, e1071, class, nnet, colourpicker, glmnet, cluster, dbscan, GGally, gbm, pROC, reshape2, scales, nortest, tseries, testthat (≥ 3.0.0), knitr, rmarkdown |
| VignetteBuilder: | knitr |
| NeedsCompilation: | no |
| Packaged: | 2026-05-13 14:11:26 UTC; ASUS |
| Author: | Mohsen Mehdinia [aut, cre] |
| Maintainer: | Mohsen Mehdinia <mehdinia.55@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-05-19 07:10:16 UTC |
Build a model formula with optional interaction terms
Description
Build a model formula with optional interaction terms
Usage
build_model_formula(
target,
features,
use_interactions = FALSE,
interaction_vars = NULL
)
Arguments
target |
Single character: response variable name. |
features |
Character vector of predictor names. |
use_interactions |
Logical; add two-way interactions? Default FALSE. |
interaction_vars |
Character vector of variables to interact. |
Value
A formula object.
Examples
build_model_formula("mpg", c("cyl", "hp", "wt"))
build_model_formula("mpg", c("cyl","hp","wt"), TRUE, c("cyl","hp"))
Compute regression performance metrics
Description
Compute regression performance metrics
Usage
ml_metrics_regression(y_true, y_pred)
Arguments
y_true |
Numeric vector of observed values. |
y_pred |
Numeric vector of predicted values. |
Value
One-row data.frame with columns RMSE, MAE, R2.
Examples
ml_metrics_regression(c(1,2,3,4,5), c(1.1,1.9,3.2,3.8,5.1))
Prepare a data frame for machine learning
Description
Prepare a data frame for machine learning
Usage
ml_prepare_data(data, target, features = NULL)
Arguments
data |
A |
target |
Single character string: the response column name. |
features |
Character vector of predictor names. Default: all except target. |
Value
Named list: data, target, features.
Examples
prep <- ml_prepare_data(mtcars, target = "mpg")
names(prep)
Split a data frame into training and test sets
Description
Split a data frame into training and test sets
Usage
ml_split(data, train_ratio = 0.8, seed = 42)
Arguments
data |
A |
train_ratio |
Numeric in (0,1); proportion for training. Default 0.8. |
seed |
Integer random seed. Default 42. |
Value
Named list with train and test data frames.
Examples
splits <- ml_split(mtcars, train_ratio = 0.75, seed = 1)
nrow(splits$train)
Run the DrData Application
Description
Launches the 'DrData' interactive 'Shiny' application for statistical analysis and machine learning workflows.
Usage
run_app()
Value
No return value, called for side effects.
Examples
if(interactive()){
run_app()
}